@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -180,5 +180,8 @@ class InventoryBatchRow(ProductBatchRowMixin, Base):
 
     @property
     def case_cost(self):
-        if self.case_quantity and self.unit_cost:
-            return self.case_quantity * self.unit_cost
+        if self.unit_cost is not None:
+            if self.unit_cost == 0:
+                return 0
+            if self.case_quantity and self.unit_cost:
+                return self.case_quantity * self.unit_cost
