@@ -255,7 +255,7 @@ class Importer(object):
         factory = factory or self.progress
         return progress_loop(func, items, factory, **kwargs)
 
-    def unique_data(self, host_data):
+    def unique_data(self, host_data, warn=True):
         # Prune duplicate keys from host/source data.  This is for the sake of
         # sanity since duplicates typically lead to a ping-pong effect, where a
         # "clean" (change-less) import is impossible.
@@ -263,8 +263,9 @@ class Importer(object):
         for data in host_data:
             key = self.get_key(data)
             if key in unique:
-                log.warning("duplicate records detected from {} for key: {}".format(
-                    self.host_system_title, key))
+                logger = log.warning if warn else log.debug
+                logger("duplicate records detected from %s for key: %s",
+                       self.host_system_title, key)
             else:
                 unique[key] = data
         return list(unique.values()), unique
@@ -354,7 +355,8 @@ class Importer(object):
             elif not local_object and self.create:
                 local_object = self.create_object(key, host_data)
                 if local_object:
-                    log.debug("created new {} {}: {}".format(self.model_name, key, local_object))
+                    log.debug("created new %s %s: %s",
+                              self.model_name, key, local_object)
                     if self.collect_changes_for_processing:
                         created.append((local_object, host_data))
                     else:
